@@ -20,9 +20,9 @@
 #include <libaio.h>
 #include "vsys_def.h"
 
-int io_submit(io_context_t ctx, int nr, struct iocb **iocbs)
+int io_submit(io_context_t ctx, long nr, struct iocb **iocbs)
 {
-	if (nr > 0)
+	if (nr >= 0)
 		return vsys_io_submit(ctx, nr, iocbs);
 	return -EINVAL;
 }
